@@ -14,8 +14,7 @@ reboot=`zenity --question --title CleaN900 --text "Are you sure you want to rest
 
 if [ "$reboot" -eq 0 ]
 	then
-		dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Restarting... Please wait..." 
-		reboot
+		dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Restarting... Please wait..." && sleep 2 && reboot
 	else
 		dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Abort!"
 fi
